==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicyReviewStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicyReviewStatusFluent<A extends io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAllowedServiceAccounts(java.lang.Integer index,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public A setToAllowedServiceAccounts(java.lang.Integer index,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public A addToAllowedServiceAccounts(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus... items);
  public A addAllToAllowedServiceAccounts(java.util.Collection<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> items);
  public A removeFromAllowedServiceAccounts(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus... items);
  public A removeAllFromAllowedServiceAccounts(java.util.Collection<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> items);
  public A removeMatchingFromAllowedServiceAccounts(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAllowedServiceAccounts instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> getAllowedServiceAccounts();
  public java.util.List<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> buildAllowedServiceAccounts();
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildAllowedServiceAccount(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildFirstAllowedServiceAccount();
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildLastAllowedServiceAccount();
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildMatchingAllowedServiceAccount(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingAllowedServiceAccount(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  public A withAllowedServiceAccounts(java.util.List<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> allowedServiceAccounts);
  public A withAllowedServiceAccounts(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus... allowedServiceAccounts);
  public java.lang.Boolean hasAllowedServiceAccounts();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> addNewAllowedServiceAccount();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> addNewAllowedServiceAccountLike(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> setNewAllowedServiceAccountLike(java.lang.Integer index,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editAllowedServiceAccount(java.lang.Integer index);
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editFirstAllowedServiceAccount();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editLastAllowedServiceAccount();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editMatchingAllowedServiceAccount(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  public interface AllowedServiceAccountsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent<io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<N>>{
    public N and();
    public N endAllowedServiceAccount();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicyReviewStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicyReviewStatusFluent<A extends io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAllowedServiceAccounts(java.lang.Integer index,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public A setToAllowedServiceAccounts(java.lang.Integer index,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public A addToAllowedServiceAccounts(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus... items);
  public A addAllToAllowedServiceAccounts(java.util.Collection<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> items);
  public A removeFromAllowedServiceAccounts(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus... items);
  public A removeAllFromAllowedServiceAccounts(java.util.Collection<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> items);
  public A removeMatchingFromAllowedServiceAccounts(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAllowedServiceAccounts instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> getAllowedServiceAccounts();
  public java.util.List<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> buildAllowedServiceAccounts();
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildAllowedServiceAccount(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildFirstAllowedServiceAccount();
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildLastAllowedServiceAccount();
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus buildMatchingAllowedServiceAccount(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingAllowedServiceAccount(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  public A withAllowedServiceAccounts(java.util.List<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus> allowedServiceAccounts);
  public A withAllowedServiceAccounts(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus... allowedServiceAccounts);
  public java.lang.Boolean hasAllowedServiceAccounts();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> addNewAllowedServiceAccount();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> addNewAllowedServiceAccountLike(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> setNewAllowedServiceAccountLike(java.lang.Integer index,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus item);
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editAllowedServiceAccount(java.lang.Integer index);
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editFirstAllowedServiceAccount();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editLastAllowedServiceAccount();
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<A> editMatchingAllowedServiceAccount(java.util.function.Predicate<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface AllowedServiceAccountsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent<io.fabric8.openshift.api.model.PodSecurityPolicyReviewStatusFluent.AllowedServiceAccountsNested<N>>{
    public N and();
    public N endAllowedServiceAccount();
    
  }
  
}
